Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
func (*Client) UploadCodex ¶
func (c *Client) UploadCodex( r *UploadCodexRequest, ) (*UploadCodexResponse, *CodexParseFailedError, error)
type CodexParseError ¶
type CodexParseFailedError ¶
type CodexParseFailedError struct {
Errors []CodexParseError `json:"errors"`
}
func (*CodexParseFailedError) Error ¶
func (e *CodexParseFailedError) Error() string
type ErrorResponse ¶
type ErrorResponse struct {
Error string `json:"error"`
Message string `json:"message"`
Details json.RawMessage `json:"details"`
}
A generic error returned by the API Consumers can inspect the value of `Error` and unmarshall `Details` as appropriate.
func (*ErrorResponse) String ¶
func (r *ErrorResponse) String() string
func (*ErrorResponse) Verbose ¶
func (r *ErrorResponse) Verbose() string
type FileRef ¶
type FileRef struct {
// The name of the file that will be uploaded.
// This is usually not the path to the file on the disk, but rather,
// the path relative to the directory that's being uploaded.
// For example, if we have a directory structure like this:
// $HOME/
// foo/
// bar.txt
// spam/
// eggs.txt
// then if we're uploading $HOME/foo, our files would have names
// "bar.txt" and "spam/eggs.txt".
Name string
// The path to the file on disk (that will be read as part of the upload)
FsPath string
}
type KernelOptions ¶ added in v0.0.12
type KernelOptions struct {
SystemPackages []string `json:"systemPackages,omitempty"`
}
type StatusError ¶
type StatusError struct {
// contains filtered or unexported fields
}
func (StatusError) Description ¶
func (s StatusError) Description() string
func (StatusError) Error ¶
func (s StatusError) Error() string
type UploadCodexRequest ¶
type UploadCodexRequest struct {
// required
// the codex category that the uploaded codex should belong to
CodexCategoryId string `json:"codexCategoryId"`
// required
// the files that comprise the codex bundle
Files []FileRef `json:"-"`
// optional
// if specified, replace this codex instead of uploading a new codex
CodexId string `json:"replaceCodexId,omitempty"`
KernelOptions KernelOptions `json:"kernelOptions"`
}
type UploadCodexResponse ¶
type UploadCodexResponse struct {
CodexId string `json:"codexId"`
}
Click to show internal directories.
Click to hide internal directories.